@@ -1115,7 +1115,7 @@ _gail_entry_insert_text_cb (GtkEntry *entry,
     {
       gail_entry->signal_name_insert = "text_changed::insert";
       gail_entry->position_insert = *position;
-      gail_entry->length_insert = arg2;
+      gail_entry->length_insert = g_utf8_strlen(arg1, arg2);
     }
   /*
    * The signal will be emitted when the cursor position is updated.
